Skip to contents

R bindings to the 'SparseDiffEngine' C library — the sparse Jacobian and Hessian differentiation backend used by 'CVXPY' for its Disciplined Nonlinear Programming (DNLP) extension. This package is the R analog of the 'sparsediffpy' Python package and wraps the same C library (pinned at the upstream v0.3.0 release).

Author

Maintainer: Balasubramanian Narasimhan naras@stanford.edu

Authors:

  • Daniel Cederberg (Author of the bundled SparseDiffEngine C library) [copyright holder]

  • William Zijie Zhang (Author of the bundled SparseDiffEngine C library) [copyright holder]